==> more_widgets-2.0.9.tar.gz: lib/widgets/form_fields/mail_form_field.dart <==
import 'package:flutter/material.dart';

class MailFormField extends StatelessWidget {
  final TextEditingController controller;
  final String labelText;
  final Function mailValidator;
  Function? onChanged;
  final FocusNode? nextFocusNode;
  final FocusNode? focusNode;
  final readOnly;
  final IconData iconData;
  final bool showUnderlineBorder;
  final Color? textColor;

  MailFormField({
      required this.controller,
      this.labelText = "Email",
      this.mailValidator = _mailValidator,
      this.onChanged,
      this.nextFocusNode,
      this.focusNode,
      this.readOnly = false,
      this.iconData = Icons.mail_rounded,
      this.showUnderlineBorder = true,
      this.textColor
    });

  @override
  Widget build(BuildContext context) {
    if (this.onChanged == null) {
      this.onChanged = (value) => print(value);
    }
    return TextFormField(
      controller: controller,
      textCapitalization: TextCapitalization.none,
      keyboardType: TextInputType.emailAddress,
      autocorrect: false,
      focusNode: focusNode,
      readOnly: readOnly,
      onEditingComplete: () => nextFocusNode == null ? FocusScope.of(context).unfocus() : FocusScope.of(context).requestFocus(nextFocusNode),
      onChanged: (value) => onChanged!(value),
      validator: (value) => mailValidator(value),
      style: TextStyle(color: textColor),
      decoration: InputDecoration(
        icon: Icon(iconData),
        labelText: labelText,
        enabledBorder: showUnderlineBorder ? null : InputBorder.none,
        focusedBorder: showUnderlineBorder ? null : InputBorder.none,
      ),
    );
  }

  static String? _mailValidator(String value) {
    if (value.trim().isEmpty) {
      return "Can't be empty";
    } else if (!value.contains('@') || !value.contains('.')) {
      return 'Email not valid';
    }
    return null;
  }
}

==> more_widgets-2.0.12.tar.gz: lib/widgets/form_fields/mail_form_field.dart <==
import 'package:flutter/material.dart';

class MailFormField extends StatelessWidget {
  final TextEditingController controller;
  final String labelText;
  final Function mailValidator;
  Function? onChanged;
  final FocusNode? nextFocusNode;
  final FocusNode? focusNode;
  final readOnly;
  final IconData iconData;
  final bool showUnderlineBorder;
  final Color? textColor;

  MailFormField({
      required this.controller,
      this.labelText = "Email",
      this.mailValidator = _mailValidator,
      this.onChanged,
      this.nextFocusNode,
      this.focusNode,
      this.readOnly = false,
      this.iconData = Icons.mail_rounded,
      this.showUnderlineBorder = true,
      this.textColor
    });

  @override
  Widget build(BuildContext context) {
    if (this.onChanged == null) {
      this.onChanged = (value) => print(value);
    }
    return TextFormField(
      controller: controller,
      textCapitalization: TextCapitalization.none,
      keyboardType: TextInputType.emailAddress,
      autocorrect: false,
      focusNode: focusNode,
      readOnly: readOnly,
      onEditingComplete: () => nextFocusNode == null ? FocusScope.of(context).unfocus() : FocusScope.of(context).requestFocus(nextFocusNode),
      onChanged: (value) => onChanged!(value),
      validator: (value) => mailValidator(value),
      style: TextStyle(color: textColor),
      decoration: InputDecoration(
        icon: Icon(iconData, color: MediaQuery.of(context).platformBrightness == Brightness.light ? Colors.white : Colors.grey.shade800,),
        labelText: labelText,
        enabledBorder: showUnderlineBorder ? null : InputBorder.none,
        focusedBorder: showUnderlineBorder ? null : InputBorder.none,
      ),
    );
  }

  static String? _mailValidator(String value) {
    if (value.trim().isEmpty) {
      return "Can't be empty";
    } else if (!value.contains('@') || !value.contains('.')) {
      return 'Email not valid';
    }
    return null;
  }
}
